#!/usr/bin/env python
import gui_qt

if __name__ == '__main__':
    gui_qt.main()
